@@ -1,8 +1,6 @@
 #!/bin/sh
 ##
-##    (C) Copyright 2012 Fred Gleason <fredg@paravelsystems.com>
-##
-##      $Id: autogen.sh,v 1.1.1.1 2014/02/17 13:26:17 cvs Exp $
+##    (C) Copyright 2012-2022 Fred Gleason <fredg@paravelsystems.com>
 ##
 ##    Adapted from './autogen.sh' in the Jack Audio Connection Kit.
 ##    Copyright (C) 2001-2003 Paul Davis, et al.
@@ -22,6 +20,13 @@
 ##    Boston, MA  02111-1307  USA
 ##
 
+#
+# Generate Debian packaging metadata
+#
+DATESTAMP=`date +%a,\ %d\ %b\ %Y\ %T\ %z`
+sed s/@VERSION@/`cat PACKAGE_VERSION`/ < debian/control.src > debian/control
+sed s/@VERSION@/`cat PACKAGE_VERSION`/ < debian/changelog.src | sed "s/@DATESTAMP@/$DATESTAMP/" > debian/changelog
+
 aclocal $ACLOCAL_FLAGS || {
     echo "aclocal \$ACLOCAL_FLAGS where \$ACLOCAL_FLAGS= failed, exiting..."
     exit 1
